@@ -24,6 +24,7 @@ from banyan.api.role import RoleAPI
 from banyan.api.service import ServiceAPI
 from banyan.api.shield import ShieldAPI
 from banyan.api.user import UserAPI
+from banyan.api.cloud_resource import CloudResourceAPI
 from banyan.core.exc import BanyanError
 
 JsonListOrObj = Union[List, Dict]
@@ -106,6 +107,16 @@ class BanyanApiClient:
         self._devices = DeviceAPI(self)
         self._events = EventV2API(self)
         self._audit = AuditAPI(self)
+        self._cloud_resources = CloudResourceAPI(self)
+
+    def __del__(self):
+        if self._http:
+            try:
+                self._http.close()
+            except Exception:
+                pass
+            finally:
+                self._http = None
 
     def _read_config_file(self):
         conf_path = Path.home() / '.banyan.conf'
@@ -113,7 +124,7 @@ class BanyanApiClient:
             try:
                 cp = configparser.ConfigParser(CONFIG)
                 cp.read(conf_path)
-                self._api_url = cp.get('banyan', 'api_url')
+                self._api_url = self._normalize_url(cp.get('banyan', 'api_url'))
                 self._refresh_token = cp.get('banyan', 'refresh_token')
             except configparser.Error:
                 pass
@@ -152,14 +163,20 @@ class BanyanApiClient:
                  hooks=None, stream=None, verify=None, cert=None, json=None) -> requests.Response:
         if '://' not in url:
             url = self._api_url + url
+        if '/v2/' in url:
+            url = url.replace('/api/v1', '/api/experimental')
         if self._insecure_tls and not verify:
             verify = False
             urllib3.disable_warnings()
         else:
             urllib3.warnings.resetwarnings()
 
-        response = self._http.request(method, url, params, data, headers, cookies, files, auth or self._http.auth,
-                                      timeout, allow_redirects, proxies, hooks, stream, verify, cert, json)
+        headers = headers or dict()
+        headers['Accept'] = 'application/json'
+        response = requests.request(
+            method=method, url=url, params=params, data=data, headers=headers, cookies=cookies, files=files,
+            auth=auth or self._http.auth, timeout=timeout, allow_redirects=allow_redirects, proxies=proxies,
+            hooks=hooks, stream=stream, verify=verify, cert=cert, json=json)
         if response.status_code >= 400:
             try:
                 content = response.json()
@@ -209,8 +226,11 @@ class BanyanApiClient:
         if data:
             headers['Content-Type'] = self.JSON_TYPE
 
-        with self._request(method=method, url=uri, params=params, data=data, headers=headers, json=json) as request:
-            return request.json()
+        with self._request(method=method, url=uri, params=params, data=data, headers=headers, json=json) as response:
+            resp = response.json()
+            if '/v2/' in uri:
+                return resp['data']
+            return resp
 
     @property
     def progress_callback(self) -> ProgressCallback:
@@ -247,7 +267,7 @@ class BanyanApiClient:
             results = self.api_request(method, uri, params, data, json, headers, accept)
             for key in results.keys():
                 logging.debug('Looking for %s in %s', key, uri)
-                if key in uri or key == 'data':
+                if key in uri or key == 'data' or key == 'result':
                     if len(results[key]) == 0:
                         return all_results
                     all_results.extend(results[key])
@@ -368,6 +388,10 @@ class BanyanApiClient:
     def audit(self) -> AuditAPI:
         return self._audit
 
+    @property
+    def cloud_resources(self) -> CloudResourceAPI:
+        return self._cloud_resources
+
 
 # configuration defaults
 CONFIG = init_defaults('banyan')
