@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Dict, Any
 
 from banyan.api.base import ServiceBase
 from banyan.model import Resource
@@ -16,7 +16,7 @@ class NetagentAPI(ServiceBase):
         uri_param = None
         obj_name = 'netagent'
 
-    def list(self) -> list:
+    def list(self, params: Dict[str, Any] = None) -> list:
         response_json = list(self._client.api_request('GET', self.Meta.list_uri))
         data: List[Resource] = self.Meta.info_class.Schema().load(response_json, many=True)
         self._build_cache(data)
