@@ -1,8 +1,7 @@
 from banyan.api.base import ServiceBase
-from banyan.model.policy import PolicyInfoOrName, PolicyAttachInfo
+from banyan.model.policy import PolicyInfo, PolicyInfoOrName, PolicyAttachInfo
 from banyan.model.service import ServiceInfo, Service, ServiceInfoOrName
 
-
 class ServiceAPI(ServiceBase):
     class Meta:
         data_class = Service
@@ -39,7 +38,7 @@ class ServiceAPI(ServiceBase):
     def test(self, service: ServiceInfoOrName) -> None:
         pass
 
-    def attached_policy(self, service: ServiceInfoOrName) -> 'PolicyInfo':
+    def attached_policy(self, service: ServiceInfoOrName) -> PolicyInfo:
         from banyan.model.policy import PolicyAttachInfo
         service = self.find(service)
         json_response = self._client.api_request('GET', f'/policy/attachment/service/{service.id}')
