@@ -9,12 +9,14 @@ from banyan.controllers.audit import AuditController
 from banyan.controllers.base import Base
 from banyan.controllers.device import DeviceController
 from banyan.controllers.event import EventV2Controller
+from banyan.controllers.export import ExportController
 from banyan.controllers.netagent import NetagentController
 from banyan.controllers.policy import PolicyController
 from banyan.controllers.role import RoleController
 from banyan.controllers.service import ServiceController
 from banyan.controllers.shield import ShieldController
 from banyan.controllers.user import UserController
+from banyan.controllers.cloud_resource import CloudResourceController
 from .core.exc import BanyanError
 
 # configuration defaults
@@ -78,6 +80,7 @@ class MyApp(App):
         # register handlers
         handlers = [
             Base,
+            CloudResourceController,
             ServiceController,
             RoleController,
             PolicyController,
@@ -87,7 +90,8 @@ class MyApp(App):
             DeviceController,
             AdminController,
             EventV2Controller,
-            AuditController
+            AuditController,
+            ExportController
         ]
 
 
